@@ -6,9 +6,9 @@ Kernel implementing matrix operations in pure Numba.
 import numpy as np
 from numba import njit
 
-from csr.layout import _CSR
-import csr.native_ops as _ops
-from .multiply import mult_ab, mult_abt
+from csr import CSR
+from .multiply import mult_ab, mult_abt  # noqa: F401
+from ...structure import sort_rows
 
 
 @njit
@@ -44,22 +44,19 @@ def order_columns(h):
     """
     Sort matrix rows in increasing column order.
     """
-    _ops.sort_rows(h)
+    sort_rows(h)
 
 
 @njit(nogil=True)
-def mult_vec(h: _CSR, v):
+def mult_vec(h: CSR, v):
     res = np.zeros(h.nrows)
 
     row = 0
     for i in range(h.nnz):
         # advance the row if necessary
-        while i == h.rowptrs[row+1]:
+        while i == h.rowptrs[row + 1]:
             row += 1
         col = h.colinds[i]
-        if h.has_values:
-            res[row] += v[col] * h.values[i]
-        else:
-            res[row] += v[col]
+        res[row] += v[col] * h._e_value(i)
 
     return res
