@@ -4,7 +4,6 @@ import pickle
 from csr import CSR
 from csr.test_utils import csrs, csr_slow
 
-from pytest import mark
 from hypothesis import given
 
 
@@ -25,12 +24,11 @@ def test_csr_pickle(csr):
         assert csr2.values is None
 
 
-@mark.skip(reason='64-bit row pointers disabled')
 @csr_slow()
 @given(csrs())
 def test_csr64_pickle(csr):
     csr = CSR(csr.nrows, csr.ncols, csr.nnz,
-              csr.rowptrs.astype(np.int64), csr.colinds, csr.values)
+              csr.rowptrs.astype(np.int64), csr.colinds, csr.values, False)
 
     data = pickle.dumps(csr)
     csr2 = pickle.loads(data)
